@@ -137,15 +137,24 @@ PROTOCOL_HTTP = 'HTTP'
 PROTOCOL_HTTPS = 'HTTPS'
 PROTOCOL_TERMINATED_HTTPS = 'TERMINATED_HTTPS'
 PROTOCOL_PROXY = 'PROXY'
+PROTOCOL_PROXYV2 = 'PROXYV2'
 PROTOCOL_SCTP = 'SCTP'
+PROTOCOL_PROMETHEUS = 'PROMETHEUS'
 SUPPORTED_PROTOCOLS = (PROTOCOL_TCP, PROTOCOL_HTTPS, PROTOCOL_HTTP,
-                       PROTOCOL_TERMINATED_HTTPS, PROTOCOL_PROXY, PROTOCOL_UDP,
-                       PROTOCOL_SCTP)
+                       PROTOCOL_TERMINATED_HTTPS, PROTOCOL_PROXY,
+                       PROTOCOL_PROXYV2, PROTOCOL_UDP, PROTOCOL_SCTP,
+                       PROTOCOL_PROMETHEUS)
 LISTENER_SUPPORTED_PROTOCOLS = (PROTOCOL_TCP, PROTOCOL_HTTPS, PROTOCOL_HTTP,
                                 PROTOCOL_TERMINATED_HTTPS, PROTOCOL_UDP,
-                                PROTOCOL_SCTP)
+                                PROTOCOL_SCTP, PROTOCOL_PROMETHEUS)
 POOL_SUPPORTED_PROTOCOLS = (PROTOCOL_TCP, PROTOCOL_HTTP, PROTOCOL_HTTPS,
-                            PROTOCOL_PROXY, PROTOCOL_UDP, PROTOCOL_SCTP)
+                            PROTOCOL_PROXY, PROTOCOL_PROXYV2, PROTOCOL_UDP,
+                            PROTOCOL_SCTP)
+
+
+ALPN_PROTOCOL_HTTP_1_0 = "http/1.0"
+ALPN_PROTOCOL_HTTP_1_1 = "http/1.1"
+ALPN_PROTOCOL_HTTP_2 = "h2"
 
 PROVISIONING_STATUS = 'provisioning_status'
 # Amphora has been allocated to a load balancer
@@ -154,6 +163,7 @@ AMPHORA_ALLOCATED = 'ALLOCATED'
 AMPHORA_BOOTING = 'BOOTING'
 # Amphora is ready to be allocated to a load balancer
 AMPHORA_READY = 'READY'
+AMPHORA_FAILOVER_STOPPED = 'FAILOVER_STOPPED'
 ACTIVE = 'ACTIVE'
 PENDING_DELETE = 'PENDING_DELETE'
 PENDING_UPDATE = 'PENDING_UPDATE'
@@ -161,6 +171,7 @@ PENDING_CREATE = 'PENDING_CREATE'
 DELETED = 'DELETED'
 SUPPORTED_PROVISIONING_STATUSES = (ACTIVE, AMPHORA_ALLOCATED,
                                    AMPHORA_BOOTING, AMPHORA_READY,
+                                   AMPHORA_FAILOVER_STOPPED,
                                    PENDING_DELETE, PENDING_CREATE,
                                    PENDING_UPDATE, DELETED, ERROR)
 
@@ -195,6 +206,7 @@ ADDITIONAL_VIPS = 'additional_vips'
 ADDRESS = 'address'
 ADMIN_STATE_UP = 'admin_state_up'
 ALLOWED_CIDRS = 'allowed_cidrs'
+ALPN_PROTOCOLS = 'alpn_protocols'
 AVAILABILITY_ZONE = 'availability_zone'
 BACKUP = 'backup'
 CA_TLS_CONTAINER_DATA = 'ca_tls_container_data'
@@ -222,6 +234,9 @@ EXPECTED_CODES = 'expected_codes'
 FALL_THRESHOLD = 'fall_threshold'
 HEALTHMONITOR = 'healthmonitor'
 HEALTHMONITOR_ID = 'healthmonitor_id'
+HSTS_MAX_AGE = 'hsts_max_age'
+HSTS_INCLUDE_SUBDOMAINS = 'hsts_include_subdomains'
+HSTS_PRELOAD = 'hsts_preload'
 HTTP_METHOD = 'http_method'
 HTTP_VERSION = 'http_version'
 INSERT_HEADERS = 'insert_headers'
@@ -281,6 +296,10 @@ VALUE = 'value'
 VIP_ADDRESS = 'vip_address'
 VIP_NETWORK_ID = 'vip_network_id'
 VIP_PORT_ID = 'vip_port_id'
+VIP_SG_IDS = 'vip_sg_ids'
 VIP_SUBNET_ID = 'vip_subnet_id'
 VIP_QOS_POLICY_ID = 'vip_qos_policy_id'
+VNIC_TYPE = 'vnic_type'
+VNIC_TYPE_DIRECT = 'direct'
+VNIC_TYPE_NORMAL = 'normal'
 WEIGHT = 'weight'
